@@ -19,6 +19,7 @@ import damo_report_access
 
 PERF = 'perf'
 perf_event_damon_aggregated = 'damon:damon_aggregated'
+perf_event_damon_monitor_intervals_tune = 'damon:damon_monitor_intervals_tune'
 perf_event_damos_before_apply = 'damon:damos_before_apply'
 
 class DamonSnapshot:
@@ -30,11 +31,13 @@ class DamonSnapshot:
     regions = None
     total_bytes = None
     damos_stats = None
+    sample_interval_us = None
 
     def update_total_bytes(self):
         self.total_bytes = sum([r.size() for r in self.regions])
 
-    def __init__(self, start_time, end_time, regions, total_bytes, damos_stats=None):
+    def __init__(self, start_time, end_time, regions, total_bytes,
+                 damos_stats=None, sample_interval_us=None):
         self.start_time = start_time
         self.end_time = end_time
         self.regions = regions
@@ -42,24 +45,34 @@ class DamonSnapshot:
         if self.total_bytes is None:
             self.update_total_bytes()
         self.damos_stats = damos_stats
+        self.sample_interval_us = sample_interval_us
 
     @classmethod
     def from_kvpairs(cls, kv):
         damos_stats = None
         if 'damos_stats' in kv and kv['damos_stats'] is not None:
             damos_stats = _damon.DamosStats.from_kvpairs(kv['damos_stats'])
+        sample_interval_us = None
+        if 'sample_interval_us' in kv and kv['sample_interval_us'] is not None:
+            sample_interval_us = _damo_fmt_str.text_to_us(
+                    kv['sample_interval_us'])
         return DamonSnapshot(
                 _damo_fmt_str.text_to_ns(kv['start_time']),
                 _damo_fmt_str.text_to_ns(kv['end_time']),
                 [_damon.DamonRegion.from_kvpairs(r) for r in kv['regions']],
                 _damo_fmt_str.text_to_bytes(kv['total_bytes'])
                 if 'total_bytes' in kv and kv['total_bytes'] is not None
-                else None, damos_stats)
+                else None, damos_stats, sample_interval_us)
 
     def to_kvpairs(self, raw=False):
         damos_stats_kv = None
         if self.damos_stats is not None:
             damos_stats_kv = self.damos_stats.to_kvpairs(raw)
+        if self.sample_interval_us is not None:
+            sample_interval_us = _damo_fmt_str.format_time_us_exact(
+                    self.sample_interval_us, raw)
+        else:
+            sample_interval_us = None
         return collections.OrderedDict([
             ('start_time', _damo_fmt_str.format_time_ns_exact(
                 self.start_time, raw)),
@@ -68,7 +81,8 @@ class DamonSnapshot:
             ('regions', [r.to_kvpairs() for r in self.regions]),
             ('total_bytes', _damo_fmt_str.format_sz(self.total_bytes, raw)
                 if self.total_bytes is not None else None),
-            ('damos_stats', damos_stats_kv)
+            ('damos_stats', damos_stats_kv),
+            ('sample_interval_us', sample_interval_us),
             ])
 
 class DamonRecord:
@@ -347,11 +361,32 @@ def parse_perf_script_line(line):
     else:
         return None, None, None, None
 
+def parse_perf_script_tune_line(line):
+    '''
+    The line is in format of, e.g.,
+    35359.794 kdamond.0/57030 damon:damon_monitor_intervals_tune(sample_us: 100000)
+
+    Return if the line is for damon_monitor_intervals_tune, and if so, the
+    sample_us value.
+     '''
+
+    fields = line.split()
+    if len(fields) != 4:
+        return False, None
+    tracepoint_name = fields[2].split('(')[0]
+    if tracepoint_name != perf_event_damon_monitor_intervals_tune:
+        return False, None
+    return True, int(fields[3].split(')')[0])
+
 def parse_perf_script(script_output, monitoring_intervals):
     records = []
     snapshot = None
+    snapshot_sample_interval_us = None
 
     for line in script_output.split('\n'):
+        parsed, snapshot_sample_interval_us = parse_perf_script_tune_line(line)
+        if parsed is True:
+            continue
         region, end_time, target_id, nr_regions = parse_perf_script_line(line)
         if region is None:
             continue
@@ -365,7 +400,10 @@ def parse_perf_script(script_output, monitoring_intervals):
                 return None, 'trace is not time-sorted'
 
         if snapshot is None:
-            snapshot = DamonSnapshot(start_time, end_time, [], None)
+            snapshot = DamonSnapshot(
+                    start_time, end_time, regions=[], total_bytes=None,
+                    damos_stats=None,
+                    sample_interval_us=snapshot_sample_interval_us)
             record.snapshots.append(snapshot)
         snapshot = record.snapshots[-1]
         snapshot.regions.append(region)
@@ -1003,7 +1041,7 @@ class RecordingHandle:
     file_permission = None
 
     # for access patterns tracing
-    tracepoint = None
+    tracepoints = None
     monitoring_intervals = None
     perf_pipe = None
 
@@ -1030,13 +1068,13 @@ class RecordingHandle:
 
     timeout = None
 
-    def __init__(self, tracepoint, file_path, file_format, file_permission,
+    def __init__(self, tracepoints, file_path, file_format, file_permission,
                  monitoring_intervals,
                  do_profile,
                  kdamonds, add_child_tasks, record_mem_footprint,
                  record_vmas, record_proc_stats, timeout, snapshot_request,
                  snapshot_interval_sec, snapshot_count):
-        self.tracepoint = tracepoint
+        self.tracepoints = tracepoints
         self.file_path = file_path
         self.file_format = file_format
         self.file_permission = file_permission
@@ -1065,16 +1103,32 @@ class RecordingHandle:
             return False
         return True
 
+def tracepoint_supported(tracepoint):
+    output = subprocess.check_output([PERF, 'list']).decode().strip()
+    for line in output.split('\n'):
+        fields = line.split()
+        if len(fields) < 3:
+            continue
+        if fields[1:3] != ['[Tracepoint', 'event]']:
+            continue
+        if fields[0] == tracepoint:
+            return True
+    return False
+
 def start_recording(handle):
     kdamonds_file_path = '%s.kdamonds' % handle.file_path
     with open(kdamonds_file_path, 'w') as f:
         json.dump([k.to_kvpairs() for k in handle.kdamonds], f, indent=4)
     os.chmod(kdamonds_file_path, handle.file_permission)
 
-    if handle.tracepoint is not None:
+    if handle.tracepoints is not None:
+        tracepoints_option = []
+        for tracepoint in handle.tracepoints:
+            if tracepoint_supported(tracepoint):
+                tracepoints_option += ['-e', tracepoint]
         handle.perf_pipe = subprocess.Popen(
-                [PERF, 'record', '-a', '-e', handle.tracepoint,
-                 '-o', handle.file_path])
+                [PERF, 'record', '-a', '-o', handle.file_path] +
+                tracepoints_option)
     if handle.do_profile:
         cmd = [PERF, 'record', '-o', '%s.profile' % handle.file_path]
         handle.perf_profile_pipe = subprocess.Popen(cmd)
@@ -1679,13 +1733,17 @@ def get_records(tried_regions_of=None, record_file=None,
             filter_copy.address_ranges = None
             filter_copy.snapshot_time_ranges = None
     else:
-        if not os.path.isfile(request.record_file):
-            return None, '%s not found' % request.record_file
+        if type(request.record_file) is not list:
+            request.record_file = [request.record_file]
+        records = []
+        for record_file in request.record_file:
+            if not os.path.isfile(record_file):
+                return None, '%s not found' % record_file
 
-        records, err = parse_records_file(request.record_file)
-        if err:
-            return None, ('parsing %s failed (%s)' %
-                    (request.record_file, err))
+            records_, err = parse_records_file(record_file)
+            if err:
+                return None, ('parsing %s failed (%s)' % (record_file, err))
+            records += records_
 
     filter_copy.filter_records(records)
     return records, None
