@@ -1,14 +1,13 @@
 # SPDX-License-Identifier: GPL-2.0
 
 import _damo_subcmds
-import damo_heatmap
 import damo_nr_regions
 import damo_report_access
 import damo_report_damon
 import damo_report_footprint
+import damo_report_heatmap
 import damo_report_holistic
 import damo_report_profile
-import damo_report_raw
 import damo_report_times
 import damo_wss
 
@@ -21,7 +20,7 @@ subcmds = [
         _damo_subcmds.DamoSubCmd(
             name='holistic', module=damo_report_holistic,
             msg='holistic report'),
-        _damo_subcmds.DamoSubCmd(name='heatmap', module=damo_heatmap,
+        _damo_subcmds.DamoSubCmd(name='heatmap', module=damo_report_heatmap,
             msg='heatmap of access patterns'),
         _damo_subcmds.DamoSubCmd(name='wss', module=damo_wss,
             msg='working set size'),
@@ -32,11 +31,6 @@ subcmds = [
             msg='hotspot functions for specific access pattern'),
         _damo_subcmds.DamoSubCmd(name='times', module=damo_report_times,
             msg='times of record having specific access pattern'),
-
-        _damo_subcmds.DamoSubCmd(name='raw', module=damo_report_raw,
-            msg=' '.join([
-                'human readable raw data of access patterns',
-                '(Will be DEPRECATED; Use "access --raw_form" instead.)'])),
         _damo_subcmds.DamoSubCmd(name='nr_regions', module=damo_nr_regions,
             msg='number of DAMON-regions'),
         ]
