@@ -82,13 +82,15 @@ snapshot_formatters = [
                   _damo_fmt_str.format_time_ns(
                       snapshot.start_time -
                       record.snapshots[0].start_time, fmt.raw_number),
-            'access monitoring start time for the snapshot, relative to the record start time'),
+                  'access monitoring start time for the snapshot, ' \
+                          'relative to the record start time'),
         Formatter('<end time>',
             lambda snapshot, record, fmt:
                   _damo_fmt_str.format_time_ns(
                       snapshot.end_time - record.snapshots[0].start_time,
                       fmt.raw_number),
-            'access monitoring end time for the snapshot, relative to the record end time'),
+                  'access monitoring end time for the snapshot, ' \
+                          'relative to the record end time'),
         Formatter('<abs start time>',
             lambda snapshot, record, fmt:
             _damo_fmt_str.format_time_ns(snapshot.start_time, fmt.raw_number),
@@ -238,16 +240,10 @@ region_formatters = [
             '<box>',
             lambda index, region, fmt:
             fmt.region_box_format.to_str(region),
-            'user-customizable (via --region_box_*) box (age/access_rate/size by default)'),
+            'user-customizable (via --region_box_*) box ' \
+                    '(age/access_rate/size by default)'),
         ]
 
-default_record_head_format = 'kdamond <kdamond index> / context <context index> / scheme <scheme index> / target id <target id> / recorded for <duration> from <abs start time>'
-default_snapshot_head_format = 'monitored time: [<start time>, <end time>] (<duration>)\n<heatmap>'
-default_snapshot_head_format_without_heatmap = 'monitored time: [<start time>, <end time>] (<duration>)'
-default_region_format = '<index> addr <start address> size <size> access <access rate> age <age>'
-default_snapshot_tail_format = 'memory bw estimate: <estimated memory bandwidth>\ntotal size: <total bytes>'
-default_snapshot_tail_format_filter_installed = 'memory bw estimate: <estimated memory bandwidth>  df-passed: <filters passed estimated memory bandwidth>\ntotal size: <total bytes>  df-passed <filters passed bytes>'
-
 def record_intervals(record, raw_number):
     intervals = record.intervals
     return 'sample %s, aggr %s' % (
@@ -305,6 +301,18 @@ def damos_stats_str(snapshot, record, fmt):
         return 'none'
     return snapshot.damos_stats.to_str(fmt.raw_number)
 
+def infer_aggr_time_us(snapshot, record):
+    if snapshot.sample_interval_us is not None:
+        aggr_sample_ratio = record.intervals.aggr / record.intervals.sample
+        return snapshot.sample_interval_us * aggr_sample_ratio
+
+    snapshot_aggr_us = (snapshot.end_time - snapshot.start_time) / 1000
+    record_aggr_us = record.intervals.aggr
+    # if error is small enough, use simpler number
+    if abs(snapshot_aggr_us - record_aggr_us) / record_aggr_us < 0.1:
+        return record_aggr_us
+    return snapshot_aggr_us
+
 def estimated_mem_bw(snapshot, record, fmt, filter_passed_only=False):
     access_bytes = 0
     for region in snapshot.regions:
@@ -313,7 +321,8 @@ def estimated_mem_bw(snapshot, record, fmt, filter_passed_only=False):
         else:
             bytes = region.size()
         access_bytes += bytes * region.nr_accesses.samples
-    bw_per_sec = access_bytes / (record.intervals.aggr / 1000000)
+    aggr_interval_sec = infer_aggr_time_us(snapshot, record) / 1000000
+    bw_per_sec = access_bytes / aggr_interval_sec
     return '%s per second' % _damo_fmt_str.format_sz(
             bw_per_sec, fmt.raw_number)
 
@@ -322,8 +331,6 @@ def filters_pass_type_of(record):
     if len(ops_filters) == 0:
         return 'n/a'
     text = ', '.join(['%s' % f for f in ops_filters])
-    if ops_filters[-1].allow is True:
-        text += '\n# WARN: Allow filters at the end of the list means nothing on <6.15'
     return text
 
 def get_linearscale_hist_ranges(minv, maxv, nr_ranges, cumulate):
@@ -378,7 +385,8 @@ def histogram_str(hist):
         y_str = '%s%s' % (y_str,
                            ' ' * (max_yval_str - len(y_str)))
 
-        nr_dots = min(math.ceil((yval - min_yval) / yval_dot_interval), max_dots)
+        nr_dots = min(math.ceil((yval - min_yval) / yval_dot_interval),
+                      max_dots)
         bar = '|%s%s|' % ('*' * nr_dots, ' ' * (max_dots - nr_dots))
         lines.append('%s %s %s' % (xrange_str, y_str, bar))
     return '\n'.join(lines)
@@ -447,7 +455,7 @@ def get_temperature(region, fmt, aggr_us):
 def temperature_sz_hist_str(snapshot, record, fmt, df_passed_sz):
     return sz_hist_str(
             snapshot, fmt, df_passed_sz, get_temperature,
-            record.intervals.aggr, _damo_fmt_str.format_nr,
+            infer_aggr_time_us(snapshot, record) , _damo_fmt_str.format_nr,
             _damo_fmt_str.text_to_nr)
 
 def get_idle_time(region, fmt, aggr_interval):
@@ -460,8 +468,9 @@ def recency_hist_str(snapshot, record, fmt, df_passed_sz):
         return 'no region in snapshot'
 
     return sz_hist_str(
-            snapshot, fmt, df_passed_sz, get_idle_time, record.intervals.aggr,
-            _damo_fmt_str.format_time_us, _damo_fmt_str.text_to_us)
+            snapshot, fmt, df_passed_sz, get_idle_time,
+            infer_aggr_time_us(snapshot, record), _damo_fmt_str.format_time_us,
+            _damo_fmt_str.text_to_us)
 
 def get_percentiles_to_show(fmt):
     percentiles_range = fmt.percentiles_range
@@ -474,13 +483,12 @@ def get_percentiles_to_show(fmt):
             percentiles_to_show = sorted(percentiles_range)
     return percentiles_to_show
 
-def get_percentile_values(snapshot, record, recency_or_temperature, df_passed,
+def get_percentile_values(snapshot, aggr_us, recency_or_temperature, df_passed,
                           percentiles_to_show, fmt):
     if recency_or_temperature == 'recency':
         get_metric_fn = get_idle_time
     else:
         get_metric_fn = get_temperature
-    aggr_us = record.intervals.aggr
     regions = sorted(snapshot.regions,
                      key=lambda r: get_metric_fn(r, fmt, aggr_us))
     if df_passed is True:
@@ -560,8 +568,8 @@ def percentiles_str(snapshot, record, fmt, df_passed, recency_or_temperature):
 
     percentiles_to_show = get_percentiles_to_show(fmt)
     percentile_values = get_percentile_values(
-            snapshot, record, recency_or_temperature, df_passed,
-            percentiles_to_show, fmt)
+            snapshot, infer_aggr_time_us(snapshot, record),
+            recency_or_temperature, df_passed, percentiles_to_show, fmt)
     return fmt_percentile_str(percentile_values, fmt, recency_or_temperature,
                               df_passed)
 
@@ -930,7 +938,8 @@ class RegionBoxFormat:
                     if self.length.display_logscale else 'linearscale'))
 
         minval, maxval = self.minmax(self.color.value_name)
-        lines.append('# color: %s (represents %s with [%d, %d] number and color (%s) in %s)'
+        lines.append('# color: %s (represents %s with [%d, %d] number and ' \
+                'color (%s) in %s)'
                 % (self.color.value_name,
                     self.format_min_max(minval, maxval,
                         self.color.value_name, raw),
@@ -1300,8 +1309,17 @@ def set_formats_hist_style(args, fmt, records):
     fmt.format_snapshot_head = '\n'.join(snapshot_head_content)
     fmt.format_region = ''
 
+def has_multiple_snapshots(records):
+    for record in records:
+        if len(record.snapshots) > 1:
+            return True
+    return False
+
 def set_formats_percentiles(args, fmt, records, recency_or_temperature):
     snapshot_head_content = []
+    if has_multiple_snapshots(records):
+        snapshot_head_content.append(
+                'snapshot time: [<start time>, <end time>] (<duration>)')
     if has_ops_filters(records):
         snapshot_head_content += [
                 '# damos filters (df): <filters passed type>',
@@ -1361,9 +1379,12 @@ def set_formats_handle_format_set_arg(fmt, format_arg):
 def set_formats_handle_styles(fmt, args, records):
     if args.style is None:
         return
+
     if args.style == 'simple-boxes':
-        fmt.format_snapshot_head = default_snapshot_head_format_without_heatmap
-        fmt.format_region = '<box> size <size> access rate <access rate> age <age>'
+        fmt.format_snapshot_head = \
+                'snapshot time: [<start time>, <end time>] (<duration>)'
+        fmt.format_region = \
+                '<box> size <size> access rate <access rate> age <age>'
         fmt.region_box_min_max_height = [1, 1]
         fmt.region_box_min_max_length = [1, 40]
         fmt.region_box_align = 'right'
@@ -1390,16 +1411,28 @@ def set_formats_handle_styles(fmt, args, records):
         fmt.sort_regions_by = ['temperature']
         fmt.sort_regions_dsc = ['temperature']
 
-def set_formats_record_default(fmt, records, intervals_tuning_enabled):
+def intervals_goal_enabled(records):
+    for record in records:
+        if record.intervals is None:
+            continue
+        if record.intervals.intervals_goal.enabled():
+            return True
+    return False
+
+def set_formats_record_default(fmt, records):
     if fmt.format_record_head == None:
         if len(records) > 1:
-            fmt.format_record_head = default_record_head_format
+            fmt.format_record_head = \
+                    'kdamond <kdamond index> / context <context index>' \
+                    ' / scheme <scheme index> / target id <target id> ' \
+                    '/ recorded for <duration> from <abs start time>'
         else:
             fmt.format_record_head = ''
-    if fmt.format_record_tail is None and intervals_tuning_enabled:
-        fmt.format_record_tail = 'monitoring intervals: <intervals>'
     if fmt.format_record_tail is None:
-        fmt.format_record_tail = ''
+        tail_lines = ['monitoring intervals: <intervals>']
+        if intervals_goal_enabled(records):
+            tail_lines.append('# <intervals goal>')
+        fmt.format_record_tail = '\n'.join(tail_lines)
 
 def set_formats_snapshot_default(fmt, records, args, ops_filters_installed):
     # handle snapshot head and tail
@@ -1410,11 +1443,14 @@ def set_formats_snapshot_default(fmt, records, args, ops_filters_installed):
                 need_snapshot_head = True
                 break
         if need_snapshot_head:
-            fmt.format_snapshot_head = default_snapshot_head_format
+            fmt.format_snapshot_head = \
+                    'snapshot time: [<start time>, <end time>] ' \
+                    '(<duration>)\n<heatmap>'
         else:
             fmt.format_snapshot_head = 'heatmap: <heatmap>'
-    if '<filters passed bytes>' in fmt.format_region:
-        fmt.format_snapshot_head += '\n# damos filters (df): <filters passed type>'
+    if ops_filters_installed:
+        fmt.format_snapshot_head += \
+                '\n# damos filters (df): <filters passed type>'
         fmt.format_snapshot_head += '\ndf-pass: <filters passed heatmap>'
 
     if args.region_box:
@@ -1422,21 +1458,32 @@ def set_formats_snapshot_default(fmt, records, args, ops_filters_installed):
             fmt.format_snapshot_tail = ('%s\n<region box description>' %
                     fmt.format_record_tail)
 
-    if fmt.format_snapshot_tail == default_snapshot_tail_format:
+    if fmt.format_snapshot_tail is None:
+        fmt.format_snapshot_tail = \
+                'memory bw estimate: <estimated memory bandwidth>\n' \
+                'total size: <total bytes>'
         if ops_filters_installed:
-            fmt.format_snapshot_tail = default_snapshot_tail_format_filter_installed
+            fmt.format_snapshot_tail = \
+                    'memory bw estimate: <estimated memory bandwidth>  ' \
+                    'df-passed: <filters passed estimated memory bandwidth>' \
+                    '\ntotal size: <total bytes>  ' \
+                    'df-passed <filters passed bytes>'
         # further check if scheme action is not stat
         if args.tried_regions_of is not None:
             fmt.format_snapshot_tail += '\nscheme stats\n<damos stats>'
 
 def set_formats_region_default(fmt, records, args):
+    default_region_format = \
+            '<index> addr <start address> size <size> access <access rate> ' \
+            'age <age>'
     if args.region_box:
         if fmt.region_box_min_max_height[1] > 1:
             fmt.format_region = '<box>%s' % default_region_format
         else:
             fmt.format_region = '<box>\n%s' % default_region_format
 
-    if fmt.format_region == default_region_format:
+    if fmt.format_region is None:
+        fmt.format_region = default_region_format
         for record in records:
             if len(record.scheme_filters) > 0:
                 fmt.format_region += ' df-passed <filters passed bytes>'
@@ -1444,17 +1491,12 @@ def set_formats_region_default(fmt, records, args):
 
 def set_formats_update_default_formats(fmt, records, args):
     ops_filters_installed = False
-    intervals_tuning_enabled = False
     for record in records:
         if len(record.scheme_filters) > 0:
             ops_filters_installed = True
-        if record.intervals is not None:
-            if record.intervals.intervals_goal.enabled():
-                intervals_tuning_enabled = True
-        if ops_filters_installed and intervals_tuning_enabled:
             break
 
-    set_formats_record_default(fmt, records, intervals_tuning_enabled)
+    set_formats_record_default(fmt, records)
     set_formats_snapshot_default(fmt, records, args, ops_filters_installed)
     set_formats_region_default(fmt, records, args)
 
@@ -1492,13 +1534,16 @@ def set_formats(args, records):
 
 def handle_ls_keywords(args):
     if args.ls_record_format_keywords:
-        print("use 'damo help access_format_options record_format_keywords' instead")
+        print("use 'damo help access_format_options record_format_keywords' " \
+                "instead")
         return True
     if args.ls_snapshot_format_keywords:
-        print("use 'damo help access_format_options snapshot_format_keywords' instead")
+        print("use 'damo help access_format_options " \
+                "snapshot_format_keywords' instead")
         return True
     if args.ls_region_format_keywords:
-        print("use 'damo help access_format_options region_format_keywords' instead")
+        print("use 'damo help access_format_options " \
+                "region_format_keywords' instead")
         return True
     return False
 
@@ -1531,7 +1576,8 @@ def translate_regions_to_cache_space(regions, cache_spec):
             if csidx >= len(set_regions):
                 print(csidx, len(set_regions))
                 exit(0)
-            set_regions[csidx].nr_accesses.samples += region.nr_accesses.samples
+            set_regions[csidx].nr_accesses.samples += \
+                    region.nr_accesses.samples
     converted = []
     for set_region in set_regions:
         if len(converted) == 0:
@@ -1628,7 +1674,8 @@ def read_and_show(args):
             break
         records, err = _damo_records.get_records(
                     tried_regions_of=args.tried_regions_of,
-                    record_file=args.input_file, snapshot_damos_filters=dfilters,
+                    record_file=args.input_file,
+                    snapshot_damos_filters=dfilters,
                     record_filter=record_filter,
                     total_sz_only=args.total_sz_only,
                     dont_merge_regions=args.dont_merge_regions)
@@ -1723,7 +1770,9 @@ def add_fmt_args(parser, hide_help=False):
     parser.add_argument('--hist_cumulate', action='store_true',
                         help='draw histogram in cumulative way')
 
-    fmt_flexible_metavar='<set|append> <record_head|snapshot_head|region|snapshot_tail|record_tail> <format string>'
+    fmt_flexible_metavar='<set|append> ' \
+            '<record_head|snapshot_head|region|snapshot_tail|record_tail> ' \
+            '<format string>'
 
     # This option also receives json string or file.  But, no real use case is
     # found.  Keep supporting for now, but hide from the help message.
@@ -1748,11 +1797,9 @@ def add_fmt_args(parser, hide_help=False):
             help=argparse.SUPPRESS)
     parser.add_argument(
             '--format_snapshot_tail', metavar='<template>',
-            default=default_snapshot_tail_format,
             # help='output format to show at the end of each snapshot'
             help=argparse.SUPPRESS)
     parser.add_argument('--format_region', metavar='<template>',
-                        default=default_region_format,
                         # help='output format to show for each memory region'
                         help=argparse.SUPPRESS)
 
@@ -1863,7 +1910,7 @@ def set_argparser(parser):
     # what to show
     _damo_records.set_filter_argparser(parser, hide_help=True)
 
-    parser.add_argument('--input_file', metavar='<file>',
+    parser.add_argument('--input_file', metavar='<file>', nargs='+',
             help='source of the access pattern to show')
     parser.add_argument('--tried_regions_of', nargs=3, type=int,
             action='append',
