@@ -50,7 +50,8 @@ class TestDamon(unittest.TestCase):
         ctx_kvpairs = ctx.to_kvpairs()
         self.assertEqual(type(ctx_kvpairs), collections.OrderedDict)
         self.assertEqual(list(ctx_kvpairs.keys()),
-                ['ops', 'targets', 'intervals', 'nr_regions', 'schemes'])
+                ['ops', 'addr_unit', 'targets', 'intervals', 'nr_regions',
+                 'schemes'])
         self.assertEqual(ctx, _damon.DamonCtx.from_kvpairs(ctx_kvpairs))
 
         kdamond = _damon.Kdamond('off', 123, [ctx])
