@@ -13,7 +13,7 @@ import _damon_args
 import _damon_sysfs
 
 class TestDamonArgs(unittest.TestCase):
-    def test_damon_ctx_for(self):
+    def test_damon_ctxs_for(self):
         _damon._damon_fs = _damon_sysfs
         _damon.set_feature_supports({'init_regions': True, 'schemes': True,
                 'schemes_stat_qt_exceed': True, 'init_regions_target_idx':
@@ -32,8 +32,9 @@ class TestDamonArgs(unittest.TestCase):
                     '--minr 10 --maxr 1000 --regions=123-456 paddr').split())
         err = _damon_args.deduce_target_update_args(args)
         self.assertEqual(err, None)
-        ctx, err = _damon_args.damon_ctx_for(args)
+        ctxs, err = _damon_args.damon_ctxs_for(args)
         self.assertEqual(err, None)
+        ctx = ctxs[0]
         self.assertEqual(ctx, _damon.DamonCtx('paddr',
             [_damon.DamonTarget(None, [_damon.DamonRegion(123, 456)])],
             _damon.DamonIntervals(5000, 100000, 1000000),
@@ -49,8 +50,9 @@ class TestDamonArgs(unittest.TestCase):
                     '--minr 10 --maxr 1,000 --regions=1K-4K paddr').split())
         err = _damon_args.deduce_target_update_args(args)
         self.assertEqual(err, None)
-        ctx, err = _damon_args.damon_ctx_for(args)
+        ctxs, err = _damon_args.damon_ctxs_for(args)
         self.assertEqual(err, None)
+        ctx = ctxs[0]
         self.assertEqual(ctx, _damon.DamonCtx('paddr',
             [_damon.DamonTarget(None, [_damon.DamonRegion(1024, 4096)])],
             _damon.DamonIntervals(5000, 100000, 1000000),
@@ -64,8 +66,9 @@ class TestDamonArgs(unittest.TestCase):
                 ('--sample 5ms --aggr 100ms --updr 1s ' +
                     '--minr 10 --maxr 1,000 --regions=1K-4K ' +
                     '--ops paddr').split())
-        ctx, err = _damon_args.damon_ctx_for(args)
+        ctxs, err = _damon_args.damon_ctxs_for(args)
         self.assertEqual(err, None)
+        ctx = ctxs[0]
         self.assertEqual(ctx, _damon.DamonCtx('paddr',
             [_damon.DamonTarget(None, [_damon.DamonRegion(1024, 4096)])],
             _damon.DamonIntervals(5000, 100000, 1000000),
@@ -73,27 +76,38 @@ class TestDamonArgs(unittest.TestCase):
 
     def test_damon_intervals_for(self):
         parser = argparse.ArgumentParser()
-        _damon_args.set_monitoring_attrs_argparser(parser)
+        _damon_args.set_monitoring_argparser(parser)
         _damon_args.set_monitoring_attrs_pinpoint_argparser(parser)
+        _damon_args.set_damos_argparser(parser, hide_help=False)
 
         args = parser.parse_args(
                 '--monitoring_intervals 4ms 120ms 1.5s'.split())
-        intervals = _damon_args.damon_intervals_for(args)
+        _damon_args.fillup_none_ctx_args(args)
+        intervals = _damon_args.damon_intervals_for(
+                args.monitoring_intervals[0], args.sample[0], args.aggr[0],
+                args.updr[0], args.monitoring_intervals_goal[0])
         self.assertEqual(intervals, _damon.DamonIntervals('4ms', '120ms',
             '1.5s'))
 
         args = parser.parse_args('--sample 7ms'.split())
-        intervals = _damon_args.damon_intervals_for(args)
+        _damon_args.fillup_none_ctx_args(args)
+        intervals = _damon_args.damon_intervals_for(
+                args.monitoring_intervals[0], args.sample[0], args.aggr[0],
+                args.updr[0], args.monitoring_intervals_goal[0])
+
         self.assertEqual(intervals, _damon.DamonIntervals('7ms'))
 
     def test_damon_nr_regions_range_for(self):
         parser = argparse.ArgumentParser()
-        _damon_args.set_monitoring_attrs_argparser(parser)
+        _damon_args.set_monitoring_argparser(parser)
         _damon_args.set_monitoring_attrs_pinpoint_argparser(parser)
+        _damon_args.set_damos_argparser(parser, hide_help=False)
 
         args = parser.parse_args(
                 '--monitoring_nr_regions_range 25 5000'.split())
-        nr_range = _damon_args.damon_nr_regions_range_for(args)
+        _damon_args.fillup_none_ctx_args(args)
+        nr_range = _damon_args.damon_nr_regions_range_for(
+                args.monitoring_nr_regions_range[0], args.minr[0], args.maxr[0])
         self.assertEqual(nr_range, _damon.DamonNrRegionsRange(25, 5000))
 
     def test_merge_ranges(self):
